<?php

namespace Garradin;

use Garradin\Plugin\RecusFiscaux\Personne;
use Garradin\Plugin\RecusFiscaux\Utils;

// vérifier si l'année a bien été sélectionnée au préalable
$_SESSION['annee_recu'] = f('annee_recu');
if (! isset($_SESSION['annee_recu']) || $_SESSION['annee_recu'] == "") {
    \Garradin\Utils::redirect(PLUGIN_URL . 'index.php');
}
$_SESSION['taux_reduction'] = $_POST['taux_reduction'];

// champs pour le nom et prénom
$confNoms = (array) $plugin->getConfig('nomChamps');
uasort($confNoms, function ($a, $b)
{
    return $a->position - $b->position;
});
$champsNom = array();
foreach ($confNoms as $nom => $champ)
{
    if ($champ->position != 0) { $champsNom[] = $nom; }
}

// versements par personne
$_SESSION['lesVersements'] = Utils::getVersementsPersonnes($_SESSION['annee_recu'],
                                                           $champsNom);

// membres donateurs
$versementsMembres = Utils::getDonateurs($_SESSION['annee_recu'],
                                         $champsNom);
$membresDonateurs = array();
foreach ($versementsMembres as $versement) {
    $membresDonateurs[$versement->idUser] = new Personne($versement->idUser,
                                                         $versement->nom,
                                                         $versement->adresse,
                                                         $versement->codePostal,
                                                         $versement->ville);
}
$_SESSION['membresDonateurs'] = $membresDonateurs;

// ------------------------------------------------------------------------
// fonctions pour l'affichage

// afficher les informations d'une personne
$tpl->register_function('afficher_debut_personne', function ($params)
{
    $versement = $params['versement'];
    $idUser = $versement->idUser;
    $personne = $_SESSION['membresDonateurs'][$idUser];
    $idVersement = $versement->idUser;
    $out = sprintf('<h3 class="personne">Versements de %s : <span id="total_%s">0,00 €</span></h3>',
                   $personne->nomPrenom,
                   $idVersement);
    $out .= sprintf('
            <fieldset class="versements" id="versements_%s">',
                    $idVersement);
    $out .= sprintf('
            <input type="checkbox" class="check_%s" id="check_%s"',
                    $idVersement,
                    $idVersement);
    $out .= sprintf(' onclick="cocherDecocherPersonne(check_%s, total_%s)" />',
                    $idVersement,
                    $idVersement);
    $out .= sprintf('
            <label for="check_%s">Cliquer pour cocher toutes les lignes</label>',
                    $idVersement);
    $out .= '<br />
             <hr>';
    return $out;
});

// afficher un versement
$tpl->register_function('afficher_versement', function ($params)
{
    $versement = $params['versement'];
    $rang = $params['rang'];
    $idVersement = $versement->idUser;
    $out = '<div class="';
    $out .= ($rang%2==0) ? 'pair">' : 'impair">';
    $out .= sprintf('
                <input type="checkbox" class="check_%s" id="check_%s_%s"
                    name="selected[]" value="%s"
                    onclick="cocherDecocherVersement(check_%s_%s, total_%s)" />
                <label for="check_%s_%s"></label>
                <span class="montant">%.2f</span>
                <span>%s</span>
            </div>',
                    $idVersement, $idVersement,
                    $rang, $rang,
                    $idVersement, $rang, $idVersement, $idVersement, $rang,
                    $versement->versement/100,
                    date_format(date_create($versement->date),"d/m/Y"));
    return $out;
});
// ------------------------------------------------------------------------

// préparation de l'affichage
$tpl->assign('lesVersements', $_SESSION['lesVersements']);
$tpl->assign('plugin_css', ['style.css']);

// envoyer au template
$tpl->display(PLUGIN_ROOT . '/templates/versements_personnes.tpl');
